# EZ Storage

mostly it is a dependency

function overview provided in `/tests/TEST.py`

## Installation:

` python -m pip install ez-storage`
## Usages:

1. used in [stable-diffusion-webui-random_prompt_generator](https://github.com/Lainupcomputer/stable-diffusion-webui-random_prompt_generator)


## Notes:
feel free to use